@@ -44,7 +44,7 @@ typedef struct {
 
 	GtkWidget         *fortune_dialog;
 	GtkWidget         *fortune_label;
-	GtkWidget         *fortune_less; 
+	GtkTextBuffer	  *fortune_buffer;
 
 	GtkWidget         *aboutbox;
 	GtkWidget         *pb;
@@ -137,7 +137,7 @@ set_wanda_day(void)
 static void
 load_image_file (Fish *fish)
 {
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf = NULL;
 	GError    *error = NULL;
 	double     affine [6];
 	guchar    *rgb;
@@ -155,19 +155,25 @@ load_image_file (Fish *fish)
 	frames = panel_applet_gconf_get_int (PANEL_APPLET (fish->applet), FISH_PREFS_FRAMES, NULL);
 
 	tmp = panel_applet_gconf_get_string (PANEL_APPLET (fish->applet), FISH_PREFS_IMAGE, NULL);
-	if (g_path_is_absolute (tmp))
+	if (g_path_is_absolute (tmp)) {
 		image = tmp;
-	else {
+	} else {
 		image = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
 						   tmp, FALSE, NULL);
+		if (image == NULL)
+			image = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
+							   tmp, FALSE, NULL);
 		g_free (tmp);
 	}
 
-	pixbuf = gdk_pixbuf_new_from_file (image, &error);
-	if (error) {
-		g_warning (G_STRLOC ": cannot open %s: %s", image, error->message);
+	if (image != NULL)
+		pixbuf = gdk_pixbuf_new_from_file (image, &error);
+	if (image == NULL || error != NULL) {
+		if (error != NULL) {
+			g_warning (G_STRLOC ": cannot open %s: %s", image, error->message);
 
-		g_error_free (error);
+			g_error_free (error);
+		}
 		g_free (image);
 		
 		if (fish_applet_rotate (fish)) {
@@ -379,31 +385,39 @@ fish_timeout(gpointer data)
 }
 
 static void
-apply_properties(Fish *fish) 
+apply_dialog_properties (Fish *fish) 
 {
 	/* xgettext:no-c-format */
 	const char *title_format = _("%s the Fish");
 	const char *label_format = _("%s the GNOME Fish Says:");
+	char *name, *tmp, *fmt;
+
+	if (fish->fortune_dialog == NULL)
+		return;
+
+	name = panel_applet_gconf_get_string (PANEL_APPLET (fish->applet),
+					      FISH_PREFS_NAME,
+					      NULL);
+
+	tmp = splice_name (title_format, name);
+	gtk_window_set_title (GTK_WINDOW (fish->fortune_dialog), tmp);
+	g_free (tmp);
+
+	fmt = g_strdup_printf ("<big><big>%s</big></big>", label_format);
+	tmp = splice_name (fmt, name);
+	g_free (fmt);
+	gtk_label_set_markup (GTK_LABEL (fish->fortune_label), tmp);
+	g_free (tmp);
+
+	g_free (name);
+}
+
+static void
+apply_properties (Fish *fish) 
+{
 	gdouble     speed;
 
-	if (fish->fortune_dialog) { 
-		gchar *name;     
-		gchar *tmp;
-
-		name = panel_applet_gconf_get_string (PANEL_APPLET (fish->applet),
-						      FISH_PREFS_NAME,
-						      NULL);
-
-		tmp = splice_name (title_format, name);
-		gtk_window_set_title (GTK_WINDOW (fish->fortune_dialog), tmp);
-		g_free (tmp);
-
-		tmp = splice_name (label_format, name);
-		gtk_label_set_text (GTK_LABEL (fish->fortune_label), tmp);
-		g_free (tmp);
-
-		g_free (name);
-	}
+	apply_dialog_properties (fish);
 	
 	load_image_file (fish);
 
@@ -471,16 +485,26 @@ fish_properties_apply_callback (GnomePropertyBox *pb,
 		    !strncmp (text, "who ", 4) ||
 		    !strcmp  (text, "who")     ||
 		    !strcmp  (text, "uptime")  ||
-		    !strncmp (text, "tail ", 5))
-			gnome_warning_dialog
-				(_("Warning:  The command appears to be "
-				   "something actually useful.\n"
-				   "Since this is a useless applet, you "
-				   "may not want to do this.\n"
-				   "We strongly advise you against "
-				   "usage of wanda for anything\n"
-				   "which would make the applet "
-				   "\"practical\" or useful."));
+		    !strncmp (text, "tail ", 5)) {
+			GtkWidget *w;
+			w = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING,
+						    GTK_BUTTONS_OK,
+						    _("Warning:  The command appears to be "
+						      "something actually useful.\n"
+						      "Since this is a useless applet, you "
+						      "may not want to do this.\n"
+						      "We strongly advise you against "
+						      "usage of wanda for anything\n"
+						      "which would make the applet "
+						      "\"practical\" or useful."));
+			gtk_window_set_wmclass (GTK_WINDOW (w), "fish_useful_warning", "Fish");
+
+			gtk_widget_show_all (w);
+
+			g_signal_connect_swapped (G_OBJECT (w), "response",
+						  G_CALLBACK (gtk_widget_destroy),
+						  G_OBJECT (w));
+		}
 	}
 
 	panel_applet_gconf_set_int (PANEL_APPLET (fish->applet),
@@ -504,12 +528,13 @@ fish_properties_apply_callback (GnomePropertyBox *pb,
 static void
 phelp_cb (GtkWidget *w, gint tab, gpointer data)
 {
-#ifdef FIXME /* figure out new help stuff */
+	GError *error = NULL;
 
-	GnomeHelpMenuEntry help_entry = { "fish_applet",
-					  "index.html#FISH-PREFS" };
-	gnome_help_display (NULL, &help_entry);
-#endif
+	gnome_help_display_desktop (NULL, "fish_applet", "fish_applet", "FISH-PREFS", &error);
+	if (error != NULL) {
+		g_warning ("help error: %s\n", error->message);
+		g_error_free (error);
+	}
 }
 
 static void 
@@ -530,9 +555,8 @@ display_properties_dialog (BonoboUIComponent *uic,
 	gdouble        speed;
 	gboolean       rotate;
 
-	if (fish->pb) {
-		gtk_widget_show (fish->pb);
-		gdk_window_raise (fish->pb->window);
+	if (fish->pb != NULL) {
+		gtk_window_present (GTK_WINDOW (fish->pb));
 		return;
 	}
 
@@ -669,7 +693,6 @@ display_properties_dialog (BonoboUIComponent *uic,
 	g_free (command);
 }
 
-#ifdef FIXME /* used in update_fortune_dialog */
 static gchar *
 fish_locate_fortune_command (Fish *fish)
 {
@@ -692,70 +715,138 @@ fish_locate_fortune_command (Fish *fish)
 
 	return command;
 }
-#endif
+
+static void
+insert_text (Fish *fish, const char *text)
+{
+	GtkTextIter iter;
+
+	gtk_text_buffer_get_iter_at_offset (fish->fortune_buffer, &iter, -1);
+
+	gtk_text_buffer_insert_with_tags_by_name (fish->fortune_buffer, &iter,
+						  text, -1,
+						  "monospace", NULL);
+}
+
+static void
+text_clear (Fish *fish)
+{
+	GtkTextIter begin, end;
+
+	gtk_text_buffer_get_iter_at_offset (fish->fortune_buffer, &begin, 0);
+	gtk_text_buffer_get_iter_at_offset (fish->fortune_buffer, &end, -1);
+
+	gtk_text_buffer_delete (fish->fortune_buffer, &begin, &end);
+
+	/* insert an empty line */
+	insert_text (fish, "\n");
+}
+
+static gboolean
+response (GtkWidget *w, int response, gpointer data)
+{
+	gtk_widget_hide (w);
+	return TRUE;
+}
+
+static gboolean
+delete_event (GtkWidget *w, gpointer data)
+{
+	gtk_widget_hide (w);
+	return TRUE;
+}
 
 static void 
 update_fortune_dialog (Fish *fish)
 {
-#ifdef FIXME /* need to replace GnomeLess */
 	char *fortune_command;
+	FILE *fp;
 
 	if ( fish->fortune_dialog == NULL ) {
+		GtkWidget *view;
+		GtkWidget *sw;
+      
 		fish->fortune_dialog = 
-			gnome_dialog_new("", GNOME_STOCK_BUTTON_CLOSE, NULL);
-		gnome_dialog_set_close(GNOME_DIALOG(fish->fortune_dialog),
-				       TRUE);
-		gnome_dialog_close_hides(GNOME_DIALOG(fish->fortune_dialog),
-					 TRUE);
+			gtk_dialog_new_with_buttons ("",
+						     NULL /* parent */,
+						     0 /* flags */,
+						     GTK_STOCK_CLOSE,
+						     GTK_RESPONSE_CLOSE,
+						     NULL);
+		g_signal_connect (G_OBJECT (fish->fortune_dialog), "delete_event",
+				  G_CALLBACK (delete_event), NULL);
+		g_signal_connect (G_OBJECT (fish->fortune_dialog), "response",
+				  G_CALLBACK (response), NULL);
 		gtk_window_set_wmclass (GTK_WINDOW (fish->fortune_dialog), "fish", "Fish");
 		gnome_window_icon_set_from_file (GTK_WINDOW (fish->fortune_dialog),
 						 GNOME_ICONDIR"/gnome-fish.png");
 
-		fish->fortune_less = gnome_less_new();
-		fish->fortune_label = gtk_label_new("");
+		gtk_window_set_default_size (GTK_WINDOW (fish->fortune_dialog),
+					     MIN (600, gdk_screen_width () * 0.9),
+					     MIN (350, gdk_screen_height () * 0.9));
 
-		gnome_less_set_fixed_font(GNOME_LESS(fish->fortune_less),TRUE);
-		
-		{
-			int i;
-			char buf[82];
-			GtkWidget *text = GTK_WIDGET(GNOME_LESS(fish->fortune_less)->text);
-			GdkFont *font = GNOME_LESS(fish->fortune_less)->font;
-			for(i=0;i<81;i++) buf[i]='X';
-			buf[i]='\0';
-			gtk_widget_set_usize(text,
-					     gdk_string_width(font,buf)+30,
-					     gdk_string_height(font,buf)*24+30);
-		}
+		view = gtk_text_view_new ();
+		gtk_text_view_set_editable (GTK_TEXT_VIEW (view), FALSE);
+		gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), FALSE);
+		gtk_text_view_set_left_margin (GTK_TEXT_VIEW (view), 10);
+		gtk_text_view_set_right_margin (GTK_TEXT_VIEW (view), 10);
+		fish->fortune_buffer =
+			gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+
+		gtk_text_buffer_create_tag (fish->fortune_buffer, "monospace",
+					    "family", "monospace",
+					    NULL);
+
+
+		sw = gtk_scrolled_window_new (NULL, NULL);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+						GTK_POLICY_AUTOMATIC,
+						GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
+						     GTK_SHADOW_IN);
+
+		gtk_container_add (GTK_CONTAINER (sw), view);
+
+		fish->fortune_label = gtk_label_new ("");
 
 		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (fish->fortune_dialog)->vbox), 
 				    fish->fortune_label,
 				    FALSE, FALSE, GNOME_PAD);
 
 		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (fish->fortune_dialog)->vbox), 
-				    fish->fortune_less,
+				    sw,
 				    TRUE, TRUE, GNOME_PAD);
 
-		gtk_widget_show (fish->fortune_less);
-		gtk_widget_show (fish->fortune_label);
-		apply_properties (fish);
+		apply_dialog_properties (fish);
+
+		gtk_widget_show_all (fish->fortune_dialog);
+	} else {
+		gtk_window_present (GTK_WINDOW (fish->fortune_dialog));
 	}
 
-	gtk_widget_show (fish->fortune_dialog);
+	text_clear (fish);
+
+	fp = NULL;
 
 	fortune_command = fish_locate_fortune_command (fish);
-	if (fortune_command) {
-                gnome_less_show_command (GNOME_LESS(fish->fortune_less),
-					 fortune_command);
-	} else {
-                gnome_less_show_string (GNOME_LESS(fish->fortune_less),
-					_("You do not have fortune installed "
-					  "or you have not specified a program "
-					  "to run.\n\nPlease refer to fish "
-					  "properties dialog."));
+	if (fortune_command != NULL) {
+		fp = popen (fortune_command, "r");
 	}
 	g_free (fortune_command);
-#endif
+
+	if (fp != NULL) {
+		char buf[2048];
+		while (fgets (buf, 2048, fp) != NULL) {
+			insert_text (fish, buf);
+		}
+		pclose (fp);
+	} else {
+		insert_text (fish, 
+			     _("You do not have fortune installed "
+			       "or you have not specified a program "
+			       "to run.\n\nPlease refer to fish "
+			       "properties dialog."));
+	}
 }
 
 static gboolean 
@@ -768,8 +859,18 @@ fish_clicked_cb (GtkWidget * widget, GdkEventButton * e, Fish *fish)
 
 	/* on 1st of april the fish is dead damnit */
 	if (fish->april_fools) {
-		gnome_ok_dialog(_("The water needs changing!\n"
-				  "(Look at today's date)"));
+		GtkWidget *w;
+		w = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_INFO,
+					    GTK_BUTTONS_OK,
+					    _("The water needs changing!\n"
+					      "(Look at today's date)"));
+		gtk_window_set_wmclass (GTK_WINDOW (w), "fish", "Fish");
+
+		gtk_widget_show_all (w);
+
+		g_signal_connect_swapped (G_OBJECT (w), "response",
+					  G_CALLBACK (gtk_widget_destroy),
+					  G_OBJECT (w));
 		return TRUE;
 	}
 
@@ -816,7 +917,6 @@ create_fish_widget(Fish *fish)
 	frames = panel_applet_gconf_get_int   (PANEL_APPLET (fish->applet), FISH_PREFS_FRAMES, NULL);
 	speed  = panel_applet_gconf_get_float (PANEL_APPLET (fish->applet), FISH_PREFS_SPEED, NULL);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	fish->darea = gtk_drawing_area_new();
@@ -847,7 +947,6 @@ create_fish_widget(Fish *fish)
         gtk_container_add(GTK_CONTAINER(fish->frame),fish->darea);
 
 	gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
 }
 
 static void
@@ -855,12 +954,13 @@ display_help_dialog (BonoboUIComponent *uic,
 		     Fish              *fish,
 		     const gchar       *verbname)
 {
-#ifdef FIXME /* figure out new help stuff */
+	GError *error = NULL;
 
-	GnomeHelpMenuEntry help_ref = { "fish_applet", "index.html"};
-
-	gnome_help_display (NULL, &help_ref);
-#endif
+	gnome_help_display_desktop (NULL, "fish_applet", "fish_applet", NULL, &error);
+	if (error != NULL) {
+		g_warning ("help error: %s\n", error->message);
+		g_error_free (error);
+	}
 }
 
 /*
@@ -878,9 +978,8 @@ display_about_dialog (BonoboUIComponent *uic,
 	gchar       *file;
 	gchar       *name;
 
-	if (fish->aboutbox) {
-		gtk_widget_show (fish->aboutbox);
-		gdk_window_raise (fish->aboutbox->window);
+	if (fish->aboutbox != NULL) {
+		gtk_window_present (GTK_WINDOW (fish->aboutbox));
 		return;
 	}
 
@@ -969,6 +1068,10 @@ applet_change_orient (PanelApplet       *applet,
 		return;
 
 	fish->orient = orient;
+
+	/* not yet all loaded up */
+	if (fish->frame == NULL)
+		return;
 	
 	load_image_file (fish);
 	
@@ -978,14 +1081,18 @@ applet_change_orient (PanelApplet       *applet,
 }
 
 static void
-applet_change_pixel_size (PanelApplet *applet,
-			  gint         size,
-			  Fish        *fish)
+applet_change_size (PanelApplet *applet,
+		    gint         size,
+		    Fish        *fish)
 {
 	if (fish->size == size)
 		return;
 
 	fish->size = size;
+
+	/* not yet all loaded up */
+	if (fish->frame == NULL)
+		return;
 	
 	load_image_file (fish);
 
@@ -1002,16 +1109,6 @@ static const BonoboUIVerb fish_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-static const char fish_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Fish Properties Item\" verb=\"FishProperties\" _label=\"Properties ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Fish Help Item\" verb=\"FishHelp\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"Fish About Item\" verb=\"FishAbout\" _label=\"About ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"</popup>\n";
-
 static gboolean
 fish_applet_fill (PanelApplet *applet)
 {
@@ -1023,14 +1120,27 @@ fish_applet_fill (PanelApplet *applet)
 	fish->size   = panel_applet_get_size (applet);
 	fish->orient = panel_applet_get_orient (applet);
 
-	panel_applet_add_preferences (applet, "/schemas/apps/fish-applet/prefs", NULL);
+	g_signal_connect (G_OBJECT (fish->applet),
+			 "destroy",
+			  G_CALLBACK (applet_destroy),
+			  fish);
+
+	g_signal_connect (G_OBJECT (fish->applet),
+			  "change_orient",
+			  G_CALLBACK (applet_change_orient),
+			  fish);
+
+	g_signal_connect (G_OBJECT (fish->applet),
+			  "change_size",
+			  G_CALLBACK (applet_change_size),
+			  fish);
+
+	panel_applet_add_preferences (applet, "/schemas/apps/fish_applet/prefs", NULL);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	bah_window = gtk_window_new (GTK_WINDOW_POPUP);
 
-	gtk_widget_pop_visual ();
 	gtk_widget_pop_colormap ();
 
 	gtk_widget_set_uposition (bah_window,
@@ -1053,23 +1163,10 @@ fish_applet_fill (PanelApplet *applet)
 
 	gtk_widget_show (GTK_WIDGET (fish->applet));
 
-	g_signal_connect (G_OBJECT (fish->applet),
-			 "destroy",
-			  G_CALLBACK (applet_destroy),
-			  fish);
-
-	g_signal_connect (G_OBJECT (fish->applet),
-			  "change_orient",
-			  G_CALLBACK (applet_change_orient),
-			  fish);
-
-	g_signal_connect (G_OBJECT (fish->applet),
-			  "change_size",
-			  G_CALLBACK (applet_change_pixel_size),
-			  fish);
-
-	panel_applet_setup_menu (PANEL_APPLET (fish->applet),
-				 fish_menu_xml,
+	panel_applet_setup_menu_from_file (PANEL_APPLET (fish->applet),
+				 NULL,
+				 "GNOME_FishApplet.xml",
+				 NULL,
 				 fish_menu_verbs,
 				 fish);
 	
