@@ -13,6 +13,8 @@
 #include <config.h>
 #endif
 
+#include <string.h>
+
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
@@ -168,18 +170,6 @@ static const BonoboUIVerb tasklist_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-static const char tasklist_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Tasklist Properties Item\" verb=\"TasklistProperties\" _label=\"Properties ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Tasklist Help Item\" verb=\"TasklistHelp\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"Tasklist About Item\" verb=\"TasklistAbout\" _label=\"About ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"</popup>\n";
-
-
-
 static void
 tasklist_properties_update_content_radio (TasklistData *tasklist)
 {
@@ -370,7 +360,7 @@ fill_tasklist_applet(PanelApplet *applet)
 	GError *error;
 	GConfValue *value;
 
-	panel_applet_add_preferences (applet, "/schemas/apps/tasklist-applet/prefs", NULL);
+	panel_applet_add_preferences (applet, "/schemas/apps/tasklist_applet/prefs", NULL);
 	
 	tasklist = g_new0 (TasklistData, 1);
 
@@ -453,7 +443,12 @@ fill_tasklist_applet(PanelApplet *applet)
 			  G_CALLBACK (applet_change_background),
 			  tasklist);
 	
-	panel_applet_setup_menu (PANEL_APPLET (tasklist->applet), tasklist_menu_xml, tasklist_menu_verbs, tasklist);
+	panel_applet_setup_menu_from_file (PANEL_APPLET (tasklist->applet),
+					   NULL,
+					   "GNOME_TasklistApplet.xml",
+					   NULL,
+					   tasklist_menu_verbs, 
+					   tasklist);
 	
 	return TRUE;
 }
@@ -467,7 +462,7 @@ display_help_dialog (BonoboUIComponent *uic,
 	GError *error = NULL;
 
 	gnome_help_display_desktop (
-			NULL, "tasklist", "tasklist", NULL, &error);
+			NULL, "window-list", "window-list", NULL, &error);
 	if (error) {
 		g_warning ("help error: %s\n", error->message);
 		g_error_free (error);
