@@ -73,10 +73,6 @@ AppletInfo *panel_applet_register    (GtkWidget      *applet,
 
 void        panel_applet_clean       (AppletInfo *info);
 
-void        panel_applet_create_menu (AppletInfo *info,
-				      gboolean    is_basep);
-
-
 void            panel_applet_add_callback    (AppletInfo  *info,
 					      const gchar *callback_name,
 					      const gchar *stock_item,
@@ -92,7 +88,8 @@ AppletUserMenu *panel_applet_get_callback    (GList       *user_menu,
 void        panel_applet_load_applets_from_gconf (void);
 void        panel_applet_save_to_gconf           (AppletInfo *applet_info);
 void        panel_applet_save_position           (AppletInfo *applet_info,
-						  const char *gconf_key);
+						  const char *gconf_key,
+						  gboolean    immediate);
 
 int         panel_applet_get_position    (AppletInfo *applet);
 gchar      *panel_applet_get_panel_id    (AppletInfo *applet);
