@@ -16,11 +16,12 @@
 #include <time.h>
 
 #include <libgnome/libgnome.h>
+#include <gconf/gconf-client.h>
+#include <gdk/gdkkeysyms.h>
+
 /* Yes, yes I know, now bugger off ... */
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
-#include <gconf/gconf-client.h>
-#include <gdk/gdkkeysyms.h>
 
 #include "foobar-widget.h"
 
@@ -43,6 +44,9 @@
 extern GlobalConfig global_config;
 extern GSList *panel_list;
 
+#define FORMAT_ITEM_NUM 4
+static GtkWidget *format_items[FORMAT_ITEM_NUM] = { NULL };
+
 extern GtkTooltips *panel_tooltips;
 
 static void foobar_widget_class_init	(FoobarWidgetClass *klass);
@@ -207,7 +211,7 @@ append_actions_menu (GtkWidget *menu_bar)
 
 	menu = panel_menu_new ();
 
-	item = pixmap_menu_item_new (_("Run..."), "gnome-run.png",
+	item = pixmap_menu_item_new (_("Run Program..."), "gnome-run.png",
 				     FALSE /* force_image */);
 	gtk_tooltips_set_tip (panel_tooltips, item,
 			      _("Run applications, if you know the "
@@ -404,41 +408,41 @@ timeout_cb (gpointer data)
 }
 
 static void
-set_fooclock_format (GtkWidget *w, char *format)
+set_fooclock_format (GtkWidget *w, const char *format)
 {
-	GList *li;
+	if ( ! GTK_CHECK_MENU_ITEM (w)->active)
+		return;
 
-	for (li = foobars; li != NULL; li = li->next) {
-		foobar_widget_set_clock_format (FOOBAR_WIDGET (li->data),
-						_(format));
-	}
+	foobar_widget_global_set_clock_format (format);
 }
 
 static void
-append_format_items (GtkWidget *menu)
+append_format_items (FoobarWidget *foo,
+		     GtkWidget    *menu)
 {
 	char hour[256];
-	GtkWidget *item;
 	GSList *group = NULL;
 	struct tm *das_tm;
 	time_t das_time = 0;
-	char *key;
+	const char *key;
 	char *str_utf8;
 	char *s;
 	int i;
-	const char *formats[] = {
+	const char *formats[FORMAT_ITEM_NUM] = {
 		N_("%H:%M"),
 		N_("%H:%M:%S"),
 		N_("%l:%M %p"),
-		N_("%l:%M:%S %p"),
-		NULL
+		N_("%l:%M:%S %p")
 	};
 
-	key = panel_gconf_global_config_get_full_key ("clock-format");
+	key = panel_gconf_full_key (
+			PANEL_GCONF_PANELS,
+			panel_gconf_get_profile (),
+			PANEL_WIDGET (foo->panel)->unique_id,
+			"clock_format");
 	s = panel_gconf_get_string (key, _("%I:%M:%S %p"));
-	g_free (key);
 	
-	for (i = 0; formats[i]; i++) {
+	for (i = 0; i < FORMAT_ITEM_NUM; i++) {
 		das_tm = localtime (&das_time);
 		if (strftime (hour, sizeof(hour), _(formats[i]), das_tm) == 0) {
  			/* according to docs, if the string does not fit, the
@@ -449,20 +453,23 @@ append_format_items (GtkWidget *menu)
 		hour[sizeof(hour)-1] = '\0'; /* just for sanity */
 
 		str_utf8 = g_locale_to_utf8 (hour, -1, NULL, NULL, NULL);
-		item = gtk_radio_menu_item_new_with_label (group, sure_string (str_utf8));
+		format_items[i] = gtk_radio_menu_item_new_with_label (group, sure_string (str_utf8));
+		g_object_set_data (G_OBJECT (format_items[i]),
+				   "Format", _(formats[i]));
+
 		g_free (str_utf8);
 
-		group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
+		group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (format_items[i]));
 	
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);	
-		g_signal_connect (G_OBJECT (item), "activate",
-			  G_CALLBACK (set_fooclock_format),
-			  (char *)formats[i]);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), format_items[i]);	
+		g_signal_connect (G_OBJECT (format_items[i]), "activate",
+				  G_CALLBACK (set_fooclock_format),
+				  _(formats[i]));
 
-		if (s && !strcmp (s, formats[i])) {
-			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), TRUE);
-		}
+		if (!strcmp (sure_string (s), _(formats[i])))
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (format_items[i]), TRUE);
 	}
+
 	g_free (s);
 }
 
@@ -509,7 +516,7 @@ append_clock_menu (FoobarWidget *foo, GtkWidget *menu_bar)
 	}
 
 	menu2 = panel_menu_new ();
-	append_format_items (menu2); 
+	append_format_items (foo, menu2); 
 
 	item = gtk_image_menu_item_new_with_label (_("Format"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), menu2);
@@ -518,7 +525,7 @@ append_clock_menu (FoobarWidget *foo, GtkWidget *menu_bar)
 	item = gtk_menu_item_new ();
 
 	foo->clock_label = gtk_label_new ("");
-	foo->clock_timeout = gtk_timeout_add (1000, timeout_cb, foo);
+	foo->clock_timeout = g_timeout_add (1000, timeout_cb, foo);
 
 	foo->clock_ebox = item;
 	gtk_container_add (GTK_CONTAINER (item), foo->clock_label);
@@ -542,10 +549,27 @@ foobar_widget_global_set_clock_format (const char *format)
 	}
 }
 
+/*
+ * FIXME: we should be only saving Foobar specific prefs
+ */
+static void
+foobar_save_to_gconf (FoobarWidget *foo)
+{
+	PanelData *pd;
+
+	pd = g_object_get_data (G_OBJECT (foo), "PanelData");
+
+	if (pd)
+		panel_save_to_gconf (pd);
+}
+
 void
 foobar_widget_set_clock_format (FoobarWidget *foo, const char *clock_format)
 {
+	int i;
+
 	g_return_if_fail (FOOBAR_IS_WIDGET (foo));
+
 	if (foo->clock_format != NULL)
 		g_free (foo->clock_format);
 	foo->clock_format = g_strdup (clock_format);
@@ -578,7 +602,28 @@ foobar_widget_set_clock_format (FoobarWidget *foo, const char *clock_format)
 		}
 		g_free (str_utf8);
 	}
+
+	/* update the menu */
+	for (i = 0; i < FORMAT_ITEM_NUM; i++) {
+		const char *item_format;
+
+		/* sanity (or insanity?) */
+		if (format_items[i] == NULL)
+			break;
+
+		item_format = g_object_get_data (G_OBJECT (format_items[i]), "Format");
+		if (strcmp (sure_string (item_format), sure_string (clock_format)) == 0) {
+			if ( ! GTK_CHECK_MENU_ITEM (format_items[i])->active)
+				gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (format_items[i]), TRUE);
+			break;
+		} else if (GTK_CHECK_MENU_ITEM (format_items[i])->active) {
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (format_items[i]), FALSE);
+		}
+	}
+
 	update_clock (foo);
+
+	foobar_save_to_gconf (foo);
 }
 
 void
@@ -666,25 +711,12 @@ get_default_image (void)
 	static GdkPixbuf *pixbuf = NULL;
 	static gboolean looked   = FALSE;
 
-	if (! looked) {
-		GdkPixbuf *pb = NULL, *scaled = NULL;
-		char *name = panel_pixmap_discovery ("gnome-tasklist.png", FALSE /* fallback */);
-		if (name == NULL)
-			/* evil fallback huh? */
-			name = panel_pixmap_discovery ("apple-red.png", FALSE /* fallback */);
-
-		if (name != NULL) {
-			pb = gdk_pixbuf_new_from_file (name, NULL);
-			g_free (name);
-		}
-		
-		if (pb != NULL) {
-			scaled = gdk_pixbuf_scale_simple (pb, 20, 20, 
-							  GDK_INTERP_BILINEAR);
-			g_object_unref (G_OBJECT (pb));
-
-			pixbuf = scaled;
-		}
+	if ( ! looked) {
+		pixbuf = panel_make_menu_icon ("gnome-tasklist.png",
+					       /* evil fallback huh? */
+					       "apple-red.png",
+					       20 /* size */,
+					       NULL /* long_operation */);
 
 		looked = TRUE;
 	}
@@ -1146,7 +1178,7 @@ foobar_widget_destroy (GtkObject *o)
 	foobars = g_list_remove (foobars, foo);
 
 	if (foo->clock_timeout != 0)
-		gtk_timeout_remove (foo->clock_timeout);
+		g_source_remove (foo->clock_timeout);
 	foo->clock_timeout = 0;
 	
 	foo->clock_label = NULL;
@@ -1201,8 +1233,7 @@ foobar_widget_new (const char *panel_id, int screen)
 
 	foo = g_object_new (FOOBAR_TYPE_WIDGET, NULL);
 
-	/* Ugly hack to reset the unique id back to the original one */	
-	if (panel_id != NULL) 
+	if (panel_id)
 		panel_widget_set_id (PANEL_WIDGET (foo->panel), panel_id);
 
 	foo->screen = screen;
