@@ -42,6 +42,7 @@
 struct _PanelAppletFramePrivate {
 	GNOME_Vertigo_PanelAppletShell  applet_shell; /* unused */
 	Bonobo_PropertyBag              property_bag;
+	BonoboUIComponent              *ui_component;
 
 	AppletInfo                     *applet_info;
 
@@ -66,14 +67,13 @@ panel_applet_frame_save_to_gconf (PanelAppletFrame *frame,
 {
 	GConfClient *client;
 	const char  *profile;
-	char        *temp_key;
+	const char  *temp_key;
 
 	client  = panel_gconf_get_client ();
 	profile = panel_gconf_get_profile ();
 
-	temp_key = panel_gconf_full_key (PANEL_GCONF_APPLETS, profile, gconf_key, "bonobo-iid");
+	temp_key = panel_gconf_full_key (PANEL_GCONF_APPLETS, profile, gconf_key, "bonobo_iid");
 	gconf_client_set_string (client, temp_key, frame->priv->iid, NULL);
-	g_free (temp_key);
 }
 
 void
@@ -83,7 +83,7 @@ panel_applet_frame_load_from_gconf (PanelWidget *panel_widget,
 {
 	GConfClient *client;
 	const char  *profile;
-	char        *temp_key;
+	const char  *temp_key;
 	char        *applet_iid;
 
 	g_return_if_fail (panel_widget != NULL);
@@ -92,9 +92,8 @@ panel_applet_frame_load_from_gconf (PanelWidget *panel_widget,
 	client  = panel_gconf_get_client ();
 	profile = panel_gconf_get_profile ();
 
-	temp_key = panel_gconf_full_key (PANEL_GCONF_APPLETS, profile, gconf_key, "bonobo-iid");
+	temp_key = panel_gconf_full_key (PANEL_GCONF_APPLETS, profile, gconf_key, "bonobo_iid");
 	applet_iid = gconf_client_get_string (client, temp_key, NULL);
-	g_free (temp_key);
 
 	panel_applet_frame_load (applet_iid, panel_widget, position, gconf_key);
 
@@ -108,6 +107,7 @@ popup_handle_remove (BonoboUIComponent *uic,
 {
 	AppletInfo *info = frame->priv->applet_info;
 	frame->priv->applet_info = NULL;
+
 	panel_applet_clean (info);
 }
 
@@ -157,20 +157,8 @@ panel_applet_frame_load (const gchar *iid,
 
 	frame = panel_applet_frame_new (panel, iid, real_key);
 
-	if (!frame) {
-		GtkWidget *dialog;
-
-		dialog = gtk_message_dialog_new (NULL,
-						 0,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_OK,
-						 _("There was a problem loading the applet."));
-		
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-		
+	if (!frame)
 		return;
-	}
 	
 	gtk_widget_show_all (frame);
 
@@ -246,7 +234,7 @@ panel_applet_frame_get_background_string (PanelAppletFrame *frame,
 		break;
 	case PANEL_BACK_COLOR:
 		retval = g_strdup_printf (
-				"color:#%.4x%.4x%.4x", 
+				"color:%.4x%.4x%.4x", 
 				panel->back_color.red, 
 				panel->back_color.green, 
 				panel->back_color.blue);
@@ -306,6 +294,14 @@ panel_applet_frame_finalize (GObject *object)
 {
 	PanelAppletFrame *frame = PANEL_APPLET_FRAME (object);
 
+	if (frame->priv->property_bag)
+		bonobo_object_release_unref (
+			frame->priv->property_bag, NULL);
+
+	if (frame->priv->ui_component)
+		bonobo_object_unref (
+			BONOBO_OBJECT (frame->priv->ui_component));
+
 	g_free (frame->priv->iid);
 	frame->priv->iid = NULL;
 
@@ -385,7 +381,7 @@ panel_applet_frame_class_init (PanelAppletFrameClass *klass,
 			      G_STRUCT_OFFSET (PanelAppletFrameClass, move_focus_out_of_applet),
 			      NULL,
 			      NULL,
-			      panel_marshal_VOID__ENUM,
+			      g_cclosure_marshal_VOID__ENUM,
 			      G_TYPE_NONE,
 			      1,
 			      GTK_TYPE_DIRECTION_TYPE);
@@ -403,6 +399,7 @@ panel_applet_frame_instance_init (PanelAppletFrame      *frame,
 
 	frame->priv->applet_shell = CORBA_OBJECT_NIL;
 	frame->priv->property_bag = CORBA_OBJECT_NIL;
+	frame->priv->ui_component = NULL;
 	frame->priv->applet_info  = NULL;
 	frame->priv->moving_focus_out = FALSE;
 	frame->priv->clean_remove = FALSE;
@@ -556,16 +553,54 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 {
 	BonoboControlFrame *control_frame;
 	Bonobo_Control      control;
-	BonoboUIComponent  *ui_component;
+	CORBA_Environment   ev;
 	GtkWidget          *widget;
 	char               *moniker;
 
 	moniker = panel_applet_frame_construct_moniker (frame, panel, iid, gconf_key);
-	widget = bonobo_widget_new_control (moniker, NULL);
+
+	/* FIXME: this should really use bonobo_get_object_async */
+	CORBA_exception_init (&ev);
+
+	control = bonobo_get_object (
+		moniker, "IDL:Bonobo/Control:1.0", &ev);
+
 	g_free (moniker);
 
+	if (BONOBO_EX (&ev)) {
+		GtkWidget *dialog;
+		char *err = bonobo_exception_get_text (&ev);
+		char *txt = g_strdup_printf (
+			_("There was a problem loading applet '%s': %s"),
+			  iid, err);
+	
+		dialog = gtk_message_dialog_new (
+			NULL,
+			GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_OK,
+			txt);
+		g_signal_connect (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy), NULL);
+	
+		gtk_widget_show (dialog);
+
+		CORBA_exception_free (&ev);
+
+		g_free (txt);
+		g_free (err);
+
+		return NULL;
+	}
+	
+	CORBA_exception_free (&ev);
+
+	widget = bonobo_widget_new_control_from_objref (control, CORBA_OBJECT_NIL);
+
+	bonobo_object_release_unref (control, NULL);
+
 	if (!widget) {
-		g_warning (G_STRLOC ": failed to load %s", iid);
+		g_warning (G_STRLOC ": failed to load applet %s", iid);
 		return NULL;
 	}
 
@@ -578,11 +613,14 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 	frame->priv->property_bag = 
 		bonobo_control_frame_get_control_property_bag (control_frame, NULL);
 
-	ui_component = bonobo_control_frame_get_popup_component (control_frame, NULL);
+	frame->priv->ui_component =
+		bonobo_control_frame_get_popup_component (control_frame, NULL);
 
-	bonobo_ui_util_set_ui (ui_component, DATADIR, "GNOME_Panel_Popup.xml", "panel", NULL);
+	bonobo_ui_util_set_ui (frame->priv->ui_component, DATADIR,
+			       "GNOME_Panel_Popup.xml", "panel", NULL);
 
-	bonobo_ui_component_add_verb_list_with_data (ui_component, popup_verbs, frame);
+	bonobo_ui_component_add_verb_list_with_data (
+		frame->priv->ui_component, popup_verbs, frame);
 
 	gtk_container_add (GTK_CONTAINER (frame), widget);
 
@@ -600,8 +638,8 @@ panel_applet_frame_new (PanelWidget *panel,
 
 	frame = g_object_new (PANEL_TYPE_APPLET_FRAME, NULL);
 
-	if (!panel_applet_frame_construct (frame, panel ,iid, gconf_key)) {
-		g_object_unref (frame);
+	if (!panel_applet_frame_construct (frame, panel, iid, gconf_key)) {
+		gtk_object_sink (GTK_OBJECT (frame));
 		return NULL;
 	}
 
